#
# spec file for package xf86-input-joystick
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           xf86-input-joystick
Version:        1.6.4
Release:        1.3
Summary:        Joystick input driver for the Xorg X server
License:        MIT
Group:          System/X11/Servers/XF86_4
URL:            https://xorg.freedesktop.org/
Source0:        https://xorg.freedesktop.org/releases/individual/driver/%{name}-%{version}.tar.xz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(inputproto)
BuildRequires:  pkgconfig(kbproto)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xorg-server) >= 1.9.99.2
BuildRequires:  pkgconfig(xproto)
Requires:       udev
Supplements:    xorg-x11-server
# This was part of the xorg-x11-driver-input package up to version 7.6
Conflicts:      xorg-x11-driver-input <= 7.6
ExcludeArch:    s390 s390x
%{x11_abi_xinput_req}

%description
joystick is an Xorg input driver for Joysticks. The driver reports
cursor movement as well as raw axis values through valuators.

%package devel
Summary:        Joystick input driver for the Xorg X server -- Development Files
Group:          Development/Libraries/X11
Requires:       %{name} = %{version}

%description devel
joystick is an Xorg input driver for Joysticks. The driver reports
cursor movement as well as raw axis values through valuators.

%prep
%setup -q

%build
%configure
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print

%post
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change || :

%postun
# re-plug the input devices
udevadm trigger --subsystem-match=input --action=change || :

%files
%license COPYING
%doc ChangeLog README.md
%dir %{_libdir}/xorg/modules/input
%{_libdir}/xorg/modules/input/joystick_drv.so
%{_mandir}/man4/joystick.4%{?ext_man}

%files devel
%{_includedir}/xorg/joystick-properties.h
%{_libdir}/pkgconfig/xorg-joystick.pc

%changelog
* Sat Dec 31 2022 Stefan Dirsch <sndirsch@suse.com>
- Update to version 1.6.4
  * Fix quoting in man page synopsis section
  * Update README for gitlab migration
  * Update configure.ac bug URL for gitlab migration
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * gitlab CI: stop requiring Signed-off-by in commits
  * autogen.sh: Implement GNOME Build API
  * autogen.sh: use quoted string variables
  * Adapt to USB HID header changes on NetBSD-8.99.9.
  * autogen: add default patch prefix
  * configure: Drop AM_MAINTAINER_MODE
  * autogen.sh: use exec instead of waiting for configure to finish
* Wed Apr 21 2021 Dirk Müller <dmueller@suse.com>
- modernize spec file:
  * use https urls
  * move license to licensedir
  * remove unnecessary attributes and add curly braces where spec-cleaner
    likes them
* Sat Nov 19 2016 tobias.johannes.klausmann@mni.thm.de
- Update to version 1.6.3:
  This release supports the X server 1.19.
* Fri Jul 31 2015 jengelh@inai.de
- Ignore absence of udevadm, it won't be present in the build env.
* Fri Jan 18 2013 zaitor@opensuse.org
- Update to version 1.6.2:
  + jast_axis: tune accelerated axis transformation to better work
    with circular axis fields (fdo#42399).
  + backend_evdev: fix scaling overflow for high resolution axes
    (fdo#42399).
  + Replace deprecated Automake INCLUDES variable with AM_CPPFLAGS.
  + configure: enable debug output code by default.
  + config:
  - Warning in default xorg.conf.d snippet: do not enable by
    default.
  - Mention use cases for when to use the module and when not to.
  + man:
  - More manpage tuning and polishing.
  - Mention use cases for when to use the module and when not to.
  - Some typos and grammar fixes.
  - Point out that the joystick module is not a joystick driver.
  + Silence compiler warnings.
* Thu Apr 19 2012 dimstar@opensuse.org
- Update to version 1.6.1:
  + Copy pInfo->driver to option list to fix hotplugging of
    keyboard device
  + unify capitalization of joystick properties
  + Return proper default for unknown values in
    pInfo->device_control.
- Use %%x11_abi_xinput_req instead of static ABI Requires.
* Wed Apr 18 2012 vuntz@opensuse.org
- Split xf86-input-joystick from xorg-x11-driver-input.
  Initial version: 1.6.0.
